from textual.app import ComposeResult
from textual.binding import Binding
from textual.widgets import Static, Button, Footer, Input, Checkbox
from textual.containers import Container, Horizontal
from textual.screen import Screen


class Header(Static):
    pass


class CommandOptions(Screen):

    def __init__(self, output, identifier, description) -> None:
        self.output = output
        self.identifier = identifier
        self.description = description
        super().__init__()

    def compose(self) -> ComposeResult:
        yield Header(f"{self.identifier}", classes="header")
        yield Footer()

    def arguments(self):
        start_arguments = False
        arguments = {}
        for index, line in enumerate(self.output, start=1):

            if "Arguments" in line:
                start_arguments = True
                continue

            if "Options" in line:
                start_arguments = False

            if start_arguments and any(word.isalpha() for word in line.split()):
                required = False
                items = line.split(" ")
                words = []
                current_word = ""
                for option in items:
                    if option and option != '│' and option != '*':
                        current_word += " " + option
                    else:
                        if option == '*':
                            required = True
                        words.append(current_word.strip())
                        current_word = ""

                words = list(filter(bool, words))
                if len(words) == 2:
                    words.insert(1, " ")
                if words:
                    words[0] = words[0].replace('--', '')
                    words[2] = words[2].replace('[', '(').replace(']', ')')
                    if required:
                        words[2] += '*'
                    if words[0] == "help":
                        continue
                arguments[words[0]] = [words[1], words[2]]

        return arguments

    def options(self):
        start = False
        options = {}
        for index, line in enumerate(self.output, start=1):
            if "Options" in line:
                start = True
                continue
            if start:
                required = False
                items = line.split(" ")
                words = []
                current_word = ""
                for option in items:
                    if option and option != '│' and option != '*':
                        current_word += " " + option
                    else:
                        if option == '*':
                            required = True
                        words.append(current_word.strip())
                        current_word = ""

                words = list(filter(bool, words))

                if words:

                    if not words[0].startswith("--") or words[0].split(",")[0].replace('--', '') == "help":
                        continue

                    words[0] = words[0].split(",")[0].replace('--', '')

                    if len(words) > 1 and words[1].startswith("-"):
                        words.remove(words[1])

                    if len(words) == 1:
                        words.append("BOOLEAN")

                    if len(words) == 2:
                        types = ["INTEGER", "FLOAT", "TEXT", "TUPLE", "UUID", "PATH", "FILENAME", "BOOLEAN"]
                        if not any(words[1].replace('[', '(').replace('<', '(').startswith(t) for t in types):
                            words.insert(1, "BOOLEAN")
                        words.append("No description")

                    for i in range(2, len(words)):
                        words[i] = words[i].replace('[', '(').replace(']', ')')
                        if required:
                            words[i] += '*'

                    options[words[0]] = words[1:]

        return options

    def on_mount(self) -> None:

        arguments = self.arguments()
        options = self.options()

        if len(arguments) != 0 or len(options) != 0:
            self.mount(Container(id="command-vertical"))

        index = 1

        if len(arguments) != 0:

            self.query_one("#command-vertical").mount(Horizontal(
                Static("Arguments", classes="command-arguments"),
                classes="command-options-bar"
                )
            )

            for k, v in arguments.items():

                description = f"{' '.join(v[1:])}"
                id = f"--argument--{k}"
                if "*" in description:
                    description = description.replace("(required)", "").replace("*", "")
                    id = f"--argument--{k}-required"
                    description = Static(f"[b]{description} [red]required[/red][/]", classes="description")
                else:
                    description = Static(f"[b]{description}[/]", classes="description")

                self.query_one("#command-vertical").mount(Container(
                    Static(f"[b][cyan]{k}[/][/]", classes="name", id=f"{id}"),
                    Static(f"[b][yellow]{v[0]}[/]", name=f"{v[0]}", classes="type"),
                    description,
                    Input(placeholder=f"...", classes="input", name="input"),
                    Button("one more", classes="buttons", id=f"one_more&{self.identifier}&{index}"),
                    classes="command-horizontal",
                    id=f"container-{index}"
                    )
                )
                index += 1

        if len(options) != 0:

            self.query_one("#command-vertical").mount(Horizontal(
                Static("Options", classes="command-options"),
                classes="command-options-bar"
                )
            )

            for k, v in options.items():

                if v[0].startswith("<"):
                    clean_string = v[0].replace("<", "").replace(">", "").replace(".", "")
                    elements = len(clean_string.split())

                    self.query_one("#command-vertical").mount(Container(
                        Static(f"[b][cyan]{k}[/][/]", classes="name", id=f"--{k}"),
                        Static(f"[b][yellow]{v[0]}[/]", name=f"{clean_string}", classes="type"),
                        Static(f"[b]{' '.join(v[1:])}[/]", classes="description"),
                        id=f"{k}",
                        classes="command-horizontal"
                        )
                    )
                    for i in range(elements):
                        self.query_one(f"#{k}").mount(
                                Input(placeholder=f"{i+1}°", classes="input", id=f"--{k}_{i+1}", name="input"),
                        )

                elif v[0] != "BOOLEAN":
                    description = f"{' '.join(v[1:])}"
                    id = k
                    if "*" in description:
                        description = description.replace("(required)", "").replace("*", "")
                        id = k + "-required"
                        description = Static(f"[b]{description} [red]required[/red][/]", classes="description")
                    else:
                        description = Static(f"[b]{description}[/]", classes="description")

                    self.query_one("#command-vertical").mount(Container(
                        Static(f"[b][cyan]{k}[/][/]", classes="name", id=f"--{id}"),
                        Static(f"[b][yellow]{v[0]}[/]", name=f"{v[0]}", classes="type"),
                        description,
                        Input(placeholder=f"...", classes="input", name="input"),
                        Button("one more", classes="buttons", id=f"one_more&{self.identifier}&{index}"),
                        classes="command-horizontal",
                        id=f"container-{index}"
                        )
                    )
                    index += 1

                else:
                    self.query_one("#command-vertical").mount(Horizontal(
                        Static(f"[b][cyan]{k}[/][/]", classes="name", id=f"--{k}"),
                        Static(f"[b][yellow]{v[0]}[/]", classes="type", name="BOOLEAN"),
                        Static(f"[b]{' '.join(v[1:])}[/]", classes="description"),
                        Checkbox(name="checkbox"),
                        classes="command-horizontal"
                        )
                    )
                    index += 1

        if len(arguments) == 0 and len(options) == 0:
            self.mount(Container(
                            Horizontal(Static("[bold][yellow]No arguments or options needed !!!\n")),
                            Horizontal(
                                Static(f"[bold] [#E1C699]{self.description}", id="description"),
                                Button("[bold]Show", id=f"show-{self.identifier}", classes="run"),
                            ),
                            classes="empty"
                    )
            )

        else:
            self.query_one("#command-vertical").mount(
                Horizontal(
                    Button("show", id=f"show-{self.identifier}", classes="run"),
                    classes="command-horizontal-run",
                    )
            )

    BINDINGS = [
        Binding(key="r", action="app.type_r('command')", description="return"),
    ]


from textual.app import ComposeResult
from textual.widgets import Static, Button, Footer, Input, Checkbox
from textual.containers import Container, Horizontal, Vertical
from textual.screen import Screen


class Header(Static):
    pass


class HomePage(Screen):

    def __init__(self, output, identifier) -> None:
        self.output = output
        self.identifier = identifier
        super().__init__()

    def title(self) -> str:
        title = ""
        for index, line in enumerate(self.output, start=1):
            if index == 4:
                title = line
                break
        if title == "" or "Options" in title:
            title = "User interface utility"

        return title.strip()

    def parse_output(self):

        start_options = False
        start_commands = False
        options = {}
        commands = []
        for index, line in enumerate(self.output, start=1):

            if "Options" in line:
                start_options = True
                continue
            if "Commands" in line:
                start_options = False
                start_commands = True
                continue
            if start_options:
                items = line.split(" ")
                words = []
                current_word = ""
                for option in items:
                    if option and option != '│' and option != '*':
                        current_word += " " + option
                    else:
                        words.append(current_word.strip())
                        current_word = ""

                words = list(filter(bool, words))

                if words:
                    if not words[0].startswith("--") or words[0].split(",")[0].replace('--', '') == "help":
                        continue
                    words[0] = words[0].split(",")[0].replace('--', '')
                    if words[0] != "help":
                        if len(words) > 1 and words[1].startswith("-"):
                            words.pop(1)
                        if len(words) == 1:
                            words.append("BOOLEAN")
                        if len(words) == 2 and not any(
                                words[1].replace('[', '(').replace('<', '(').startswith(t) for t in
                                ["INTEGER", "FLOAT", "TEXT", "<", "UUID", "PATH", "FILENAME", "BOOLEAN"]):
                            words.insert(1, "BOOLEAN")
                        words[2:] = [w.replace('[', '(').replace(']', ')') for w in words[2:]]
                        options[words[0]] = words[1:] + (["No description"] if len(words) == 2 else [])

            elif start_commands and any(word.isalpha() for word in line.split()):
                command = line.split(" ")
                words = []
                current_word = ""
                for item in command:
                    if item and item != '│':
                        current_word += " " + item
                    else:
                        words.append(current_word.strip())
                        current_word = ""
                words = list(filter(bool, words))

                if words:
                    if len(words) == 1:
                        words.append("No description")

                commands.append(words)

        return options, commands

    def compose(self) -> ComposeResult:
        yield Header("Homepage", classes="header")
        yield Footer()

    def on_mount(self) -> None:

        container = None

        title = self.title()
        self.mount(Static(f"[green][bold]{title}", classes="title"))
        self.mount(Vertical(id="homepage-vertical"))

        options, commands = self.parse_output()

        if options:
            self.query_one(Vertical).mount(Horizontal(
                    Static("Options"),
                    classes="homepage-options-bar"
                )
            )
            for k, v in options.items():

                if v[0] == "BOOLEAN":
                    container = Container(
                        Static(f"[cyan][bold]{k}", classes="name", id=f"--{k}"),
                        Static(f"[b][yellow]{v[0]}[/]", name=f"{v[0]}", classes="type"),
                        Static(f"[bold]{v[1]}", classes="description-bool"),
                        Checkbox(name="checkbox"),
                        classes="homepage-horizontal"
                    )
                elif not v[0].startswith("["):
                    description = v[1].replace("(required)", "").strip()
                    id = k if "(required)" not in v[1] else f"{k}-required"
                    required_label = " [red](required)[/red]" if "(required)" in v[1] else ""
                    description = Static(f"[bold]{description}{required_label}", classes="description")
                    is_password = True if k == "password" else False

                    container = Container(
                        Static(f"[cyan]{k}", classes="name", id=f"--{id}"),
                        Static(f"[b][yellow]{v[0]}[/]", name=f"{v[0]}", classes="type"),
                        description,
                        Input(placeholder=f"{k}", password=is_password, name=f"{v[0]}&{k}", classes="input"),
                        classes="homepage-horizontal"
                    )

                self.query_one(Vertical).mount(container)

        if commands:
            self.query_one(Vertical).mount(Horizontal(
                Static("Commands"),
                classes="homepage-commands-bar"
                )
            )
            for command in commands:
                button = Button(command[0], id=command[0])
                description = Static(f"[bold][#E1C699]{command[1]}")
                command_horizontal = Horizontal(button, description, classes="homepage-command")

                self.query_one(Vertical).mount(command_horizontal)



import sys
import subprocess

from textual.app import App
from textual.binding import Binding
from textual.widgets import Button, Input
from textual import events
from textual.pilot import Pilot

from rich.console import Console
from typing import Tuple, List

from typer_to_textual.command_options import CommandOptions
from typer_to_textual.homepage import HomePage
from typer_to_textual.show import Show


def maximize() -> None:
    result = subprocess.run(["xdotool", "getactivewindow"], capture_output=True)
    window_id = result.stdout.decode().strip()

    res = subprocess.check_output("xrandr | grep '\*' | awk '{print $1}'", shell=True).decode().strip().split('x')
    screen_width = int(res[0])
    screen_height = int(res[1])

    if screen_width <= 1366 and screen_height <= 768:
        window_size = "80%"
    else:
        window_size = "70%"

    subprocess.run(["xdotool", "windowsize", window_id, window_size, window_size])

    window_width = int(window_size[:-1]) / 100 * screen_width
    window_height = int(window_size[:-1]) / 100 * screen_height
    x_pos = int((screen_width - window_width) / 2)
    y_pos = int((screen_height - window_height) / 2)

    subprocess.run(["xdotool", "windowmove", window_id, str(x_pos), str(y_pos)])


def homepage_output() -> Tuple[List[str], str]:

    if len(sys.argv) != 2:
        Console().print("[bold][red]Error[/red]: Pass only the name of application")
        sys.exit(1)

    application = sys.argv[1]
    command = application.split()
    command.append("--help")
    maximize()

    try:
        result = subprocess.run(command, capture_output=True)
        found = False
        for line in result.stdout.decode().split('\n'):
            if "Options" in line or "Commands" in line:
                found = True
        if not found:
            for i in result.stderr.decode().split('\n'):
                if i:
                    print(i.rstrip())
            Console().print(f"[bold][red]Error[/red]: The executable is not a typer application")
            sys.exit(1)
        return result.stdout.decode().split('\n'), application

    except FileNotFoundError:
        Console().print(f"[bold][red]Error[/red]: The application: '{application}' is not found")
        sys.exit(1)


class Tui(App):

    def __init__(self) -> None:
        self.output, self.application = homepage_output()
        super().__init__()

    CSS_PATH = "style.css"

    BINDINGS = [
        Binding(key="escape", action="key_escape", description="exit"),
    ]

    def on_mount(self) -> None:
        self.install_screen(HomePage(self.output, "homepage"), name="homepage")
        self.push_screen("homepage")

    async def on_key(self, event: events.Key):
        if event.key == "up":
            pilot = Pilot(self)
            await pilot.press("shift+tab")
        if event.key == "down":
            pilot = Pilot(self)
            await pilot.press("tab")

    def action_key_escape(self) -> None:
        self.exit()

    def call_command(self, command: str, homepage_data) -> List[str]:

        maximize()

        application = self.application
        args = application.split()

        for option in homepage_data:
            args.append(option)

        args.append(command)
        args.append("--help")

        result = subprocess.run(args, capture_output=True)

        return result.stdout.decode().split('\n')

    def command_buttons(self):
        start_commands = False
        buttons = {}
        for index, line in enumerate(self.output, start=1):

            if "Commands" in line:
                start_commands = True
                continue

            if start_commands and any(word.isalpha() for word in line.split()):
                command = line.split(" ")
                words = []
                current_word = ""
                for item in command:
                    if item and item != '│':
                        current_word += " " + item
                    else:
                        words.append(current_word.strip())
                        current_word = ""

                words = list(filter(bool, words))
                buttons[words[0]] = words[1]

        return buttons

    def check_fields(self, elements: str, page: str):

        validation_errors = False

        screen_class = "HomePage" if page == "homepage" else "CommandOptions"

        for screens in self.query(f"{screen_class}"):
            if screens.identifier == page:
                for element in screens.query(f".{elements}"):
                    input_type = ''
                    tuple_types = []

                    for index, static_element in enumerate(element.query("Static"), start=1):
                        if index == 2 and static_element.name != "BOOLEAN":
                            tuple_types = static_element.name.split(" ")
                            if len(tuple_types) == 1:
                                if tuple_types[0] == "INTEGER":
                                    input_type = "INTEGER"
                                elif tuple_types[0] == "FLOAT":
                                    input_type = "FLOAT"
                                else:
                                    input_type = "TEXT"
                            elif static_element.name.startswith("<"):
                                input_type = "TUPLE"
                            else:
                                input_type = "ARGUMENT"

                    if input_type == "ARGUMENT":
                        break

                    if input_type == "INTEGER" or input_type == "FLOAT":
                        for input_element in element.query(".input"):
                            try:
                                if input_element.value != "":
                                    if input_type == "INTEGER":
                                        int(input_element.value)
                                    else:
                                        float(input_element.value)
                                input_element.styles.border = None
                            except ValueError:
                                validation_errors = True
                                input_element.styles.border = ("tall", "red")

                    elif input_type == "TUPLE":
                        for index, input_element in enumerate(element.query(".input")):
                            expected_type = {
                                "INTEGER": int,
                                "TEXT": str,
                                "FLOAT": float
                            }.get(tuple_types[index], None)

                            try:
                                if input_element.value != "":
                                    expected_type(input_element.value)
                                input_element.styles.border = None
                            except ValueError:
                                validation_errors = True
                                input_element.styles.border = ("tall", "red")

                for element in screens.query(f".{elements}"):
                    for index, e in enumerate(element.query("Static"), start=1):
                        if index == 1:
                            key = e.id
                            if "-required" in key:
                                for input_element in element.query(".input"):
                                    if input_element.value == "":
                                        validation_errors = True
                                        input_element.styles.border = ("tall", "red")
                                    else:
                                        input_element.styles.border = None

        return validation_errors

    def homepage_field(self) -> list:

        homepage_data = []
        for element in self.query_one(HomePage).query(".homepage-horizontal"):
            key = element.query_one(".name").id.replace("-required", "")
            if len(element.query("Input")) > 0:
                for i in element.query("Input"):
                    if i.value != '':
                        homepage_data.append(key)
                        homepage_data.append(i.value)
            else:
                for i in element.query("Checkbox"):
                    if str(i.value) == "True":
                        homepage_data.append(key)

        return homepage_data

    def command_page_field(self, command):

        tuple_data = {}
        other_data = []
        command = command.replace("show-", "")
        for screens in self.query(CommandOptions):
            if screens.identifier == command:
                for element in screens.query(".command-horizontal"):
                    key = element.query_one(".name").id
                    if len(element.query(".input")) > 0:
                        if "-required" in key:
                            key = key.replace("-required", "")
                        diversi = len(set(i.placeholder for i in element.query(".input"))) > 1
                        if diversi:
                            for i in element.query(".input"):
                                if i.value != '':
                                    if key not in tuple_data:
                                        tuple_data[key] = [i.value]
                                    else:
                                        tuple_data[key].append(i.value)
                        else:
                            for i in element.query(".input"):
                                if "--argument--" in key and i.value != '':
                                    other_data.append(i.value)
                                elif i.value != '':
                                    other_data.append(key)
                                    other_data.append(i.value)
                    else:
                        if "-required" in key:
                            key = key.replace("-required", "")
                        if str(element.query_one("Checkbox").value) == "True":
                            tuple_data[key] = "BOOL"

        return tuple_data, other_data

    def on_button_pressed(self, event: Button.Pressed):

        values = self.command_buttons()
        buttons = values.keys()

        if event.button.id in buttons:

            validation_errors = self.check_fields("homepage-horizontal", "homepage")
            if validation_errors:
                return

            description = values[event.button.id]
            homepage_data = self.homepage_field()

            if not self.is_screen_installed(event.button.id):
                result = self.call_command(event.button.id, homepage_data)
                self.install_screen(CommandOptions(result, event.button.id, description), name=event.button.id)
            self.push_screen(event.button.id)

        elif event.button.id.startswith("show-"):

            command = event.button.id.replace("show-", "")
            validation_errors = self.check_fields("command-horizontal", command)
            if validation_errors:
                return

            homepage_data = self.homepage_field()
            tuple_data, other_data = self.command_page_field(command)

            if not self.is_screen_installed(event.button.id):
                self.install_screen(Show(self.application, command, homepage_data, tuple_data, other_data), name=event.button.id)
            self.push_screen(event.button.id)

        elif event.button.id.startswith("one_"):

            id, index = event.button.id.split("&")[1:]
            for screens in self.query(CommandOptions):
                if screens.identifier == id:
                    container = screens.query_one(f"#container-{index}")
                    input_elements = container.query("Input")
                    if event.button.id.startswith("one_more"):
                        if len(input_elements) == 1:
                            container.mount(Button("one less", classes="buttons", id=f"one_less&{id}&{index}"), after=4)
                        input_element = Input(placeholder=f"...", classes="input")
                        container.mount(input_element, before=3)
                    elif event.button.id.startswith("one_less") and len(input_elements) > 1:
                        input_elements.first().remove()
                        if len(container.query("Input")) == 1:
                            container.query("Button").last().remove()

    async def action_type_r(self, screen):

        input_has_focus = any(i.has_focus for i in self.query("Input"))

        if input_has_focus:
            for i in self.query("Input"):
                if i.has_focus:
                    i.value = i.value + 'r'
                    pilot = Pilot(self)
                    await pilot.press("right")
                    break
        else:
            if screen == "show":
                self.uninstall_screen(self.pop_screen())
            else:
                self.pop_screen()






import asyncio
import subprocess

from textual.app import ComposeResult
from textual.binding import Binding
from textual.widgets import Static, Footer
from textual.containers import Container
from textual.screen import Screen


class Header(Static):
    pass


class Show(Screen):

    def __init__(self, application, command, homepage_data=None, command_tuple_data=None, command_other_data=None) -> None:
        self.application = application
        self.command = command
        self.homepage_data = homepage_data
        self.command_tuple_data = command_tuple_data
        self.command_other_data = command_other_data
        super().__init__()

    def compose(self) -> ComposeResult:
        yield Header("Show", classes="header")
        yield Container(
                Static("[bold][yellow]Operation in progress....", id="loading"),
                id="show-container")
        yield Footer()

    async def run_button(self):

        application = self.application
        args = application.split()

        for option in self.homepage_data:
            args.append(option)

        args.append(self.command)

        for key, value in self.command_tuple_data.items():
            args.append(key)
            if value != "BOOL":
                if isinstance(value, list):
                    for val in value:
                        args.append(val)
                else:
                    values = value.split(",")
                    for val in values:
                        args.append(val.strip())

        for element in self.command_other_data:
            args.append(element)

        result = subprocess.run(args, capture_output=True)

        output = result.stdout.decode().split('\n')
        stderr_lines = result.stderr.decode().split('\n')

        await self.query_one("#loading").remove()
        for row in output:
            await self.query_one("#show-container").mount(Static(f"[bold]{row}", classes="output"))
        for error in stderr_lines:
            await self.query_one("#show-container").mount(Static(f"[bold]{error}", classes="output"))

    async def on_mount(self) -> None:
        await asyncio.sleep(0.1)
        asyncio.create_task(self.run_button())

    BINDINGS = [
        Binding(key="r", action="app.type_r('show')", description="return"),
    ]


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['typer_to_textual']

package_data = \
{'': ['*']}

install_requires = \
['rich>=13.3.2,<14.0.0', 'textual>=0.10.1,<0.11.0', 'typer>=0.7.0,<0.8.0']

extras_require = \
{':python_version >= "3.10" and python_version < "4.0"': ['xdotool>=0.4.0,<0.5.0']}

setup_kwargs = {
    'name': 'typer-to-textual',
    'version': '2.5.0',
    'description': '',
    'long_description': '# typer-to-texual\n\n**typer-to-textual** is a TUI developed through the Textual module, which aims to simplify \nthe use of applications. This tool analyzes the help screens of different typer applications and creates \na TUI that allows the user to select the desired commands and options easily and intuitively, without the \nneed to know all available commands and options by heart. In summary, the use of the interactive TUI \nrepresents a major step forward in simplifying the use of typer applications and making them more accessible \nto all users, even the less experienced ones.\n\n## Install\n\nAs a preliminary requirement, you need to install some utility:\n\n**xdotool**. Installs the package via prompt with the command: \'sudo apt-get install xdotool\'\n\nAfter that, you can proceed either via PyPI, or by cloning the repository and install dependencies.\nIf you opt for PyPI, run the following command:\n```bash\n$ pip install typer-to-textual\n```\n\nAfter that, **typer-to-textual** can be run with:\n```bash\n$ python3 -m typer-to-textual [typer_application]\n```\n\nIf you instead opt for the repository, you also need the [Poetry](https://python-poetry.org/) Python package manager.\nOn Debian-like OSes it can be installed with the following command:\n```bash\n$ sudo apt install python3-poetry\n```\nAfter that, run the following commands:\n```bash\n$ git clone https://github.com/palla98/typer-to-textual.git\n```\n\nafter downloading:\n```bash\n$ cd typer-to-textual\n\n$ poetry install\n```\n\nAfter that, **typer-to-textual** can be run with:\n```bash\n$ poetry run ./typer_to_textual.py [typer_application]\n```\n\nse però [typer_application] è \'**python3 -m [nome_modulo]**\' bisogna stare attenti perchè si utlizza\nl\'interprete Python dell\'ambiente virtuale creato da Poetry. Quindi bisogna andare ad installare \n[nome_modulo] nell\'ambiente virtuale altrimenti non viene riconosciuto.\n\noppure semplicemente si può lanciare il comando:\n```bash\npython3 typer_to_textual.py \'python3 -m [nome_modulo]\'\n```\n\nla cosa migliore è andare a creare uno script .sh in modo tale da passare direttamente un eseguibile\nLo si va a creare e salvare nella tua directory bin personale:\n(~/.local/bin/[nome_script].sh):\n```bash\nsudo nano ~/.local/bin/[nome_script].sh\n```\n\n```bash\n#!/bin/bash\n\nOLD_PWD=$PWD\n\ncd path/to/executable\npoetry run ./executable "$@"\ncd $PWD\n```\nIn seguito renderlo eseguibile con questo comando:\n```bash\nsudo chmod +x ~/.local/bin/[nome_script].sh\n```\n\ne poi andare a creare un link simbolico:\n```bash\nsudo ln -s  ~/.local/bin/[nome_script].sh ~/.local/bin/[nome_script]\n```\nDopodichè semplicemente basterà chiamare lo script digitando semplicemente il comando [nome_script]\nda qualsiasi posizione nel terminale.\n\nquindi si potrà usare typer-to-textual anche in questo modo senza avere problemi di ambiente virtuale:\n```bash\npoetry run ./typer_to_textual.py [nome_script]\n```',
    'author': 'palla98',
    'author_email': 'pallaria98@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
